automake-ng
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Automake-NG] [FYI] [ng] rename: am__ensure_dir_exists -> am.cmd.ensure-


From: Stefano Lattarini
Subject: [Automake-NG] [FYI] [ng] rename: am__ensure_dir_exists -> am.cmd.ensure-dir-exists
Date: Tue, 31 Jul 2012 19:29:38 +0200

Signed-off-by: Stefano Lattarini <address@hidden>
---
 lib/am/depend2.am      |  2 +-
 lib/am/header-vars.mk  |  4 ++--
 t/ensure-dir-exists.sh | 10 +++++-----
 3 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/lib/am/depend2.am b/lib/am/depend2.am
index 2601434..d52af03 100644
--- a/lib/am/depend2.am
+++ b/lib/am/depend2.am
@@ -37,7 +37,7 @@ am__depdir = $(dir $@)/$(DEPDIR)
 ## FIXME: more precise in the removal of the suffix?
 am__depbase = $(am__depdir)/$(basename $(notdir $@))
 ## Avoid useless forks when possible.
-am__ensure_depdir = $(call am__ensure_dir_exists,$(am__depdir))
+am__ensure_depdir = $(call am.cmd.ensure-dir-exists,$(am__depdir))
 am__o_src = $(if $(filter .obj,$(suffix $@)),`$(CYGPATH_W) $<`,$<)
 ## To facilitate use of "libtool --dry-run".
 am__mv = mv -f
diff --git a/lib/am/header-vars.mk b/lib/am/header-vars.mk
index b2fb450..f899813 100644
--- a/lib/am/header-vars.mk
+++ b/lib/am/header-vars.mk
@@ -127,12 +127,12 @@ V ?= 0
 # try to optimize for those cases -- especially because, for our
 # usage patterns, one of them should always be true in non-VPATH
 # builds.
-am__ensure_dir_exists = \
+am.cmd.ensure-dir-exists = \
   $(if $(filter .,$1),:,$(if $(wildcard $1/),:,$(MKDIR_P) $1))
 
 # Ensure the directory containing the target of the current recipe
 # exists, by creating it if necessary.
-am__ensure_target_dir_exists = $(call am__ensure_dir_exists,$(@D))
+am__ensure_target_dir_exists = $(call am.cmd.ensure-dir-exists,$(@D))
 
 # The 'all' target must be the default one, independently from the
 # position it is declared in the output Makefile.
diff --git a/t/ensure-dir-exists.sh b/t/ensure-dir-exists.sh
index 28f6c4b..9d35470 100755
--- a/t/ensure-dir-exists.sh
+++ b/t/ensure-dir-exists.sh
@@ -14,7 +14,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Test Automake-provided internal macro 'am__ensure_dir_exists'.
 
 am_create_testdir=empty
 . ./defs || exit 1
@@ -32,13 +32,13 @@ all: $(files)
 .PHONY: all
 
 sanity-check:
-       $(warning $(call am__ensure_dir_exists,x))
-       $(if $(filter $(call am__ensure_dir_exists,x),:MKDIR_P:),, \
-             $(error am__ensure_dir_exists does not contain $$(MKDIR_P)))
+       $(warning $(call am.cmd.ensure-dir-exists,x))
+       $(if $(filter $(call am.cmd.ensure-dir-exists,x),:MKDIR_P:),, \
+             $(error am.cmd.ensure-dir-exists does not contain $$(MKDIR_P)))
 .PHONY: sanity-check
 
 $(files):
-       $(call am__ensure_dir_exists,x)
+       $(call am.cmd.ensure-dir-exists,x)
        echo dummy > $@
 END
 
@@ -14,7 +14,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-# Test Automake-provided internal macro 'am__ensure_dir_exists'.
+# Test Automake-provided internal macro 'am.cmd.ensure-dir-exists'.
 
 am_create_testdir=empty
-- 
1.7.12.rc0




reply via email to

[Prev in Thread] Current Thread [Next in Thread]